Index: pkg/kernel/lib/transformations/flags.dart |
diff --git a/pkg/kernel/lib/transformations/flags.dart b/pkg/kernel/lib/transformations/flags.dart |
index 093ff23e0cce16b818cdb026f81cc17b75bf719e..32cd627f1f7e8ac61396491d8ff806692bc1d4fc 100644 |
--- a/pkg/kernel/lib/transformations/flags.dart |
+++ b/pkg/kernel/lib/transformations/flags.dart |
@@ -12,9 +12,9 @@ class TransformerFlag { |
/// [SuperPropertyGet], [SuperPropertySet], [SuperMethodInvocation]. |
static const int superCalls = 1 << 0; |
/// Temporary flag used by sanity checks to indicate that the given member |
/// has been seen. |
- static const int seenBySanityCheck = 1 << 1; |
+ static const int seenByVerifier = 1 << 1; |
// TODO(asgerf): We could also add a flag for 'async' and will probably have |
// one for closures as well. |
@@ -12,9 +12,9 @@ class TransformerFlag { |
/// [SuperPropertyGet], [SuperPropertySet], [SuperMethodInvocation]. |
static const int superCalls = 1 << 0; |
- /// Temporary flag used by sanity checks to indicate that the given member |
+ /// Temporary flag used by the verifier to indicate that the given member |
/// has been seen. |